pub struct MockAccountBillingVNextApi {
AccountBillingVNextApi_expectations: MockAccountBillingVNextApi_AccountBillingVNextApi,
}Fields
AccountBillingVNextApi_expectations: MockAccountBillingVNextApi_AccountBillingVNextApiImplementations
Sourceimpl MockAccountBillingVNextApi
impl MockAccountBillingVNextApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockAccountBillingVNextApi
impl MockAccountBillingVNextApi
Sourcepub fn expect_add_credit_via_bit_pay(&mut self) -> &mut Expectation
pub fn expect_add_credit_via_bit_pay(&mut self) -> &mut Expectation
Create an Expectation for mocking the add_credit_via_bit_pay method
Sourcepub fn expect_create_portal_session(&mut self) -> &mut Expectation
pub fn expect_create_portal_session(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_portal_session method
Create an Expectation for mocking the create_premium_checkout_session method
Sourcepub fn expect_create_subscription(&mut self) -> &mut Expectation
pub fn expect_create_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_subscription method
Sourcepub fn expect_get_applicable_discounts(&mut self) -> &mut Expectation
pub fn expect_get_applicable_discounts(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_applicable_discounts method
Sourcepub fn expect_get_credit(&mut self) -> &mut Expectation
pub fn expect_get_credit(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_credit method
Sourcepub fn expect_get_license(&mut self) -> &mut Expectation
pub fn expect_get_license(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_license method
Sourcepub fn expect_get_payment_method(&mut self) -> &mut Expectation
pub fn expect_get_payment_method(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_payment_method method
Sourcepub fn expect_get_subscription(&mut self) -> &mut Expectation
pub fn expect_get_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_subscription method
Sourcepub fn expect_reinstate_subscription(&mut self) -> &mut Expectation
pub fn expect_reinstate_subscription(&mut self) -> &mut Expectation
Create an Expectation for mocking the reinstate_subscription method
Sourcepub fn expect_update_payment_method(&mut self) -> &mut Expectation
pub fn expect_update_payment_method(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_payment_method method
Sourcepub fn expect_update_subscription_storage(&mut self) -> &mut Expectation
pub fn expect_update_subscription_storage(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_subscription_storage method
Create an Expectation for mocking the upgrade_premium_to_organization method